@@ -90,7 +90,7 @@ class DM(object):
         """
         return self.__get_response_element_data('duration', 'text')
 
-    def get_closest_points(self, max_distance=None, num=10, origin_index=0, origin_raw=None):
+    def get_closest_points(self, max_distance=None, num=-1, origin_index=0, origin_raw=None):
         """
         Get closest points to a given origin. Returns a list of 2 element tuples where first element is the destination and the second is the distance.
         """
